ABICOMP character set - Wikipedia

# ABICOMP character set

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

The ABICOMP Character Set was an encoded repertoire of characters used in Brazil. It was devised by the Associação Brasileira de Indústria de Computadores, a Brazilian computer industry association defunct[1] in 1992. It was used on Brazilian-made computers and several printers brands.[2][3][4] This code page is known by Star printers and FreeDOS as Code page 3848.

## Coverage[edit]

The ABICOMP Character Set obviously contained the characters to cover Portuguese. It also contained characters to cover other languages such as Spanish, French, Italian and German. However, the quotation marks “«” and “»” for (European) Portuguese, (European) Spanish, French and Italian are missing.

This character set[5] was different from the Brazilian Standard BraSCII,[6] which was very similar to ISO 8859-1. Although once very used in Brazil, this character set became less and less used because of the ubiquity of other character sets (ISO 8859-1 and later Unicode).

## Character set[edit]

ABICOMP
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
1_ 16 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
2_ 32 | SP 0020 | ! 0021 | " 0022 | # 0023 | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ 48 | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ 64 | @ 0040 | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ 80 | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B | \ 005C | ] 005D | ^ 005E | _ 005F
6_ 96 | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ 112 | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B | | 007C | } 007D | ~ 007E |
8_ 128 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
9_ 144 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
A_ 160 | NBSP 00A0 | À 00C0 | Á 00C1 | Â 00C2 | Ã 00C3 | Ä 00C4 | Ç 00C7 | È 00C8 | É 00C9 | Ê 00CA | Ë 00CB | Ì 00CC | Í 00CD | Î 00CE | Ï 00CF | Ñ 00D1
B_ 176 | Ò 00D2 | Ó 00D3 | Ô 00D4 | Õ 00D5 | Ö 00D6 | Œ 0152 | Ù 00D9 | Ú 00DA | Û 00DB | Ü 00DC | Ÿ 0178 | ¨ 00A8 | £ 00A3 | ¦ 00A6 | § 00A7 | ° 00B0
C_ 192 | ¡ 00A1 | à 00E0 | á 00E1 | â 00E2 | ã 00E3 | ä 00E4 | ç 00E7 | è 00E8 | é 00E9 | ê 00EA | ë 00EB | ì 00EC | í 00ED | î 00EE | ï 00EF | ñ 00F1
D_ 208 | ò 00F2 | ó 00F3 | ô 00F4 | õ 00F5 | ö 00F6 | œ 0153 | ù 00F9 | ú 00FA | û 00FB | ü 00FC | ÿ 00FF | ß 00DF | ª 00AA | º 00BA | ¿ 00BF | ± 00B1
E_ 224 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
F_ 240 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |

Letter Number Punctuation Symbol Other Undefined

## References[edit]

1. ^
   "A batalha dos protocolos de redes de computadores localizada (no Brasil) no fim do Século XX" (PDF). Archived from the original (PDF) on 2017-12-15. Retrieved 2017-02-25.
2. ^ Epson Stylus Color 200 User Guide
3. ^ Star LC 8021 User's Manual
4. ^ Brother HL-2135W Symbol and character sets list
5. ^ OkiPOS425D Developer's Guide ABICOMP Code Table
6. ^ OkiPOS425D Developer's Guide BraSCII Code Table

Retrieved from "https://en.wikipedia.org/w/index.php?title=ABICOMP_character_set&oldid=963949530"
Categories:

- Character sets